import math

import pygame
import os

DIAL_SIZE = 500
SCREEN_SIZE = 720
FPS = 60
PI = 3.14159265

script_dir = os.path.dirname(os.path.abspath(__file__))


class Dial(pygame.sprite.Sprite):
    def __init__(self):
        super().__init__()
        self._base_image = pygame.image.load(script_dir + '/resources/dial-face.png')
        self.position = 0
        self.rotation = 77 - (2 * 77.5 * self.position)
        self.image = pygame.transform.rotate(self._base_image, self.rotation)
        self.rect = self._base_image.get_rect()
        self.test_cw = True

    def update(self):
        if self.test_cw:
            self.position += 0.01
        else:
            self.position -= 0.01
        if self.position > 1:
            self.position = 1
            self.test_cw = not self.test_cw
        if self.position < 0:
            self.position = 0
            self.test_cw = not self.test_cw
        self.rotation = 77 - (2 * 77.5 * self.position)
        self.image = pygame.transform.rotate(self._base_image, self.rotation)
        self.rect = self.image.get_rect(center=self.rect.center)
        self.rect.center = (math.sin(math.radians(self.rotation)) * -300 + 360,
                            math.cos(math.radians(self.rotation + 180)) * 300 + 360)


def main(windowed_mode):
    pygame.init()
    clock = pygame.time.Clock()
    if windowed_mode:
        window = pygame.display.set_mode((SCREEN_SIZE, SCREEN_SIZE))
    else:
        window = pygame.display.set_mode((SCREEN_SIZE, SCREEN_SIZE), pygame.FULLSCREEN)

    bg_image = pygame.image.load(script_dir + '/resources/dial-bg.png')

    dial = Dial()

    all_sprites = pygame.sprite.Group(dial)

    def draw():
        # Draws all the sprites on a black background
        all_sprites.update()
        window.blit(bg_image, (0, 0))
        all_sprites.draw(window)

        # Update the entire display
        pygame.display.flip()

    running = True
    while running:
        clock.tick(FPS)

        # pygame.mouse.set_visible(False)

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                running = False
            if event.type == pygame.KEYDOWN:
                if event.key == pygame.K_ESCAPE:
                    running = False

        mouse_pos = pygame.mouse.get_pos()

        draw()

    pygame.quit()
